<!--
SPDX-FileCopyrightText: 2020 IntelMQ Team

SPDX-License-Identifier: AGPL-3.0-or-later
-->

![IntelMQ](https://raw.githubusercontent.com/certtools/intelmq/master/docs/images/Logo_Intel_MQ.png)

**IntelMQ Manager** is a graphical interface to manage configurations for the [IntelMQ](https://github.com/certtools/intelmq) framework.
A IntelMQ configuration is a set of config files which describe which bots and processing steps should be run in which order. It is similar to describing the dataflow in [dataflow oriented](https://en.wikipedia.org/wiki/Dataflow_programming) languages.
**IntelMQ Manager** is therefore an intuitive tool to allow non-programmers to specify the data flow in IntelMQ.

## Documentation

The documentation for IntelMQ-Manager is part of the [IntelMQ documentation on readthedocs](https://intelmq.readthedocs.io/en/latest/user/intelmq-manager.html).

## Licence

This software (IntelMQ and its components) is licensed under these licenses:
 * Apache License 2.0
 * GNU Affero Public License version v3.0
 * MIT License

See [LICENSES](LICENSES) for all license texts and [debian/copyright](debian/copyright) for a list of components and it's licenses.
